@@ -1,41 +1,31 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "kdeapplicationdebugsettingpage.h"
 #include "kdeapplicationtreelistwidget.h"
 #include <KLocalizedString>
-#include <QPushButton>
-#include <QVBoxLayout>
 #include <QEvent>
 #include <QKeyEvent>
+#include <QPushButton>
+#include <QVBoxLayout>
 #include <ktreewidgetsearchline.h>
 
 KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     : QWidget(parent)
+    , mTreeListWidget(new KDEApplicationTreeListWidget(this))
+    , mTreeListWidgetSearchLine(new KTreeWidgetSearchLine(this, mTreeListWidget))
+    , mEnableDebug(new QPushButton(i18n("Enable All Debug"), this))
+    , mTurnOffDebug(new QPushButton(i18n("Turn Off Debug"), this))
+    , mTurnOffAllMessages(new QPushButton(i18n("Turn Off All Messages"), this))
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    mTreeListWidget = new KDEApplicationTreeListWidget(this);
     mTreeListWidget->setObjectName(QStringLiteral("listwidget"));
 
-    mTreeListWidgetSearchLine = new KTreeWidgetSearchLine(this, mTreeListWidget);
     mTreeListWidgetSearchLine->setPlaceholderText(i18n("Search..."));
     mTreeListWidgetSearchLine->setObjectName(QStringLiteral("searchline"));
     mTreeListWidgetSearchLine->setSearchColumns(mTreeListWidget->searchColumns());
@@ -43,20 +33,17 @@ KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
 
     mainLayout->addWidget(mTreeListWidget);
 
-    auto *buttonLayout = new QHBoxLayout;
+    auto buttonLayout = new QHBoxLayout;
     mainLayout->addLayout(buttonLayout);
 
-    mEnableDebug = new QPushButton(i18n("Enable All Debug"), this);
     mEnableDebug->setObjectName(QStringLiteral("selectall"));
     buttonLayout->addWidget(mEnableDebug);
     connect(mEnableDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotSelectAllDebug);
 
-    mTurnOffDebug = new QPushButton(i18n("Turn Off Debug"), this);
     mTurnOffDebug->setObjectName(QStringLiteral("deselectall"));
     buttonLayout->addWidget(mTurnOffDebug);
     connect(mTurnOffDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAllDebug);
 
-    mTurnOffAllMessages = new QPushButton(i18n("Turn Off All Messages"), this);
     mTurnOffAllMessages->setObjectName(QStringLiteral("deselectallmessage"));
     buttonLayout->addWidget(mTurnOffAllMessages);
     connect(mTurnOffAllMessages, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAllMessages);
@@ -76,7 +63,7 @@ void KDEApplicationDebugSettingPage::forceFocus()
 bool KDEApplicationDebugSettingPage::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress && obj == mTreeListWidgetSearchLine) {
-        auto *key = static_cast<QKeyEvent *>(event);
+        auto key = static_cast<QKeyEvent *>(event);
         if ((key->key() == Qt::Key_Enter) || (key->key() == Qt::Key_Return)) {
             event->accept();
             return true;
