@@ -1,54 +1,45 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "kdebugsettingsdialog.h"
-#include "customdebugsettingspage.h"
-#include "kdeapplicationdebugsettingpage.h"
-#include "environmentsettingsrulespage.h"
-#include "kdebugsettingsutil.h"
 #include "categorywarning.h"
-#include "loadcategoriesjob.h"
-#include "saverulesjob.h"
-
-#include <KLocalizedString>
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <KMessageBox>
-
-#include <QFileDialog>
-#include <QDialogButtonBox>
-#include <QLibraryInfo>
-#include <QTabWidget>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QDir>
-#include <QDesktopServices>
-#include <QUrl>
+#include "customdebugsettingspage.h"
+#include "environmentsettingsrulespage.h"
+#include "groupmanagementdialog.h"
+#include "kdeapplicationdebugsettingpage.h"
 #include "kdebugsettings_debug.h"
-namespace {
+#include "kdebugsettingsutil.h"
+#include "loadcategoriesjob.h"
+#include "loadgroupmenu.h"
+#include "loadtoolbutton.h"
+#include "saverulesjob.h"
+#include "savetoolbutton.h"
+
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+
+#include <QDesktopServices>
+#include <QDialogButtonBox>
+#include <QFileDialog>
+#include <QInputDialog>
+#include <QPushButton>
+#include <QTabWidget>
+#include <QUrl>
+#include <QVBoxLayout>
+namespace
+{
 constexpr char KDebugSettingsDialogGroupName[] = "KDebugSettingsDialog";
 }
 KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     mCategoryWarning = new CategoryWarning(this);
     mCategoryWarning->setObjectName(QStringLiteral("categorywarning"));
@@ -69,20 +60,27 @@ KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     mTabWidget->addTab(mEnvironmentSettingsRulesPage, i18n("Rules Settings With Environment Variable"));
     mTabWidget->setFocusPolicy(Qt::NoFocus);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help
+                                              | QDialogButtonBox::Apply,
+                                          this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
 
-    QPushButton *saveAs = new QPushButton(i18n("Save As..."), this);
+    auto saveAs = new SaveToolButton(this);
+    saveAs->setText(i18n("Save As..."));
     saveAs->setObjectName(QStringLiteral("saveas_button"));
     buttonBox->addButton(saveAs, QDialogButtonBox::ActionRole);
-    connect(saveAs, &QPushButton::clicked, this, &KDebugSettingsDialog::slotSaveAs);
+    connect(saveAs, &SaveToolButton::saveAsFile, this, &KDebugSettingsDialog::slotSaveAs);
+    connect(saveAs, &SaveToolButton::saveAsGroup, this, &KDebugSettingsDialog::slotSaveAsGroup);
 
-    QPushButton *load = new QPushButton(i18n("Load..."), this);
-    load->setObjectName(QStringLiteral("load_button"));
-    buttonBox->addButton(load, QDialogButtonBox::ActionRole);
-    connect(load, &QPushButton::clicked, this, &KDebugSettingsDialog::slotLoad);
+    mLoadToolButton = new LoadToolButton(this);
+    mLoadToolButton->setObjectName(QStringLiteral("load_button"));
+    buttonBox->addButton(mLoadToolButton, QDialogButtonBox::ActionRole);
+    connect(mLoadToolButton, &LoadToolButton::loadFromFile, this, &KDebugSettingsDialog::slotLoad);
+    connect(mLoadToolButton, &LoadToolButton::loadGroupRequested, this, &KDebugSettingsDialog::slotLoadGroup);
+    connect(mLoadToolButton, &LoadToolButton::manageGroupRequested, this, &KDebugSettingsDialog::slotManageGroup);
+    connect(this, &KDebugSettingsDialog::updateLoadGroupMenu, mLoadToolButton, &LoadToolButton::updateLoadGroupMenu);
 
-    QPushButton *insertCategories = new QPushButton(i18n("Insert..."), this);
+    auto insertCategories = new QPushButton(i18n("Insert..."), this);
     insertCategories->setObjectName(QStringLiteral("insert_button"));
     buttonBox->addButton(insertCategories, QDialogButtonBox::ActionRole);
     connect(insertCategories, &QPushButton::clicked, this, &KDebugSettingsDialog::slotInsertCategories);
@@ -119,13 +117,21 @@ void KDebugSettingsDialog::saveConfig()
     group.sync();
 }
 
+void KDebugSettingsDialog::slotLoadGroup(const QString &fullPath)
+{
+    if (!fullPath.isEmpty()) {
+        mLoggings.readCategoriesFiles(fullPath);
+        updateLoggingCategories();
+    }
+}
+
 void KDebugSettingsDialog::readQtLoggingFile()
 {
     mLoggings.readQtLoggingFile();
-    updateLogginsCategories();
+    updateLoggingCategories();
 }
 
-void KDebugSettingsDialog::updateLogginsCategories()
+void KDebugSettingsDialog::updateLoggingCategories()
 {
     if (!mLoggings.environmentrules().isEmpty()) {
         mEnvironmentSettingsRulesPage->setRules(mLoggings.environmentrules());
@@ -179,7 +185,8 @@ void KDebugSettingsDialog::slotApply()
 
 void KDebugSettingsDialog::slotInsertCategories()
 {
-    const QString path = QFileDialog::getOpenFileName(this, i18n("Insert Categories"), QString(), QStringLiteral("%1 (*.categories)").arg(i18n("Categories Files")));
+    const QString path =
+        QFileDialog::getOpenFileName(this, i18n("Insert Categories"), QString(), QStringLiteral("%1 (*.categories)").arg(i18n("Categories Files")));
     if (!path.isEmpty()) {
         const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategoriesList);
         LoggingCategory::List newCategories;
@@ -196,6 +203,21 @@ void KDebugSettingsDialog::slotInsertCategories()
     }
 }
 
+void KDebugSettingsDialog::slotSaveAsGroup()
+{
+    const QString groupPath = LoadGroupMenu::defaultWritableGroupPath();
+    const QString name = QInputDialog::getText(this, i18n("Group Name"), i18n("Name"));
+    const QString trimmedName = name.trimmed();
+    if (!trimmedName.isEmpty()) {
+        if (mLoadToolButton->groupNames().contains(trimmedName)) {
+            KMessageBox::error(this, i18n("%1 is already used as a group name.\nPlease save as another name.", trimmedName));
+        } else {
+            saveRules(groupPath + QLatin1Char('/') + trimmedName, true);
+            Q_EMIT updateLoadGroupMenu();
+        }
+    }
+}
+
 void KDebugSettingsDialog::slotSaveAs()
 {
     const QString path = QFileDialog::getSaveFileName(this, i18n("Save As"), QString(), i18n("KDebugSettings File (*.kdebugsettingsrules)"));
@@ -209,7 +231,7 @@ void KDebugSettingsDialog::slotLoad()
     const QString path = QFileDialog::getOpenFileName(this, i18n("Load Debug Settings Files"), QString(), i18n("KDebugSettings File (*.kdebugsettingsrules)"));
     if (!path.isEmpty()) {
         mLoggings.readCategoriesFiles(path);
-        updateLogginsCategories();
+        updateLoggingCategories();
     }
 }
 
@@ -217,3 +239,11 @@ void KDebugSettingsDialog::slotRestoreDefault()
 {
     mKdeApplicationSettingsPage->restoreToDefault();
 }
+
+void KDebugSettingsDialog::slotManageGroup()
+{
+    auto groupManagementDialog = new GroupManagementDialog(this);
+    connect(groupManagementDialog, &GroupManagementDialog::groupsChanged, this, &KDebugSettingsDialog::updateLoadGroupMenu);
+    groupManagementDialog->exec();
+    delete groupManagementDialog;
+}
